@@ -2,9 +2,9 @@
 # vim: et ts=4 :
 #
 # PyarrFS - a RAR reading file system
-# Copyright (c) 2010, 2011 Kristian Larsson <kristian@spritelink.net>
+# Copyright (c) 2010-2012 Kristian Larsson <kristian@spritelink.net>
 #
-# This file is license under the X11/MIT license, please see the file COPYING
+# This file is licensed under the X11/MIT license, please see the file COPYING,
 # distributed with PyarrFS for more details.
 #
 
@@ -27,11 +27,13 @@ except:
 try:
     import rarfile
 except:
-    print >> sys.stderr, "You do not have the Python module for rarlib installed"
-    print >> sys.stderr, "Please note that you need a non-standard version of rarfile available from \nhttp://git.spritelink.net/gitweb?p=rarfile.git"
+    print >> sys.stderr, "You do not have the Python module for the library rarfile installed"
+    print >> sys.stderr, "Please use your distributions package manager or easy_install to get it. Note\nthat you need version 2.3 or later. To install using easy_install:\n  easy_install rarfile"
     sys.exit(1)
 
-__version__         = '0.7.2'
+rarfile.NEED_COMMENTS = 0
+
+__version__         = '0.8.0'
 __author__          = 'Kristian Larsson'
 __author_email__    = 'kristian@spritelink.net'
 __license__         = 'MIT'
@@ -73,12 +75,14 @@ class Pyarr(fuse.Fuse):
 
         fuse.Fuse.__init__(self, *args, **kw)
 
+        self.no_compressed = False
         self.debug = False
         self.pydebug = False
         self.foreground = False
         self.root = '/'
 
 
+
     def fsinit(self):
         """Called once for initialising things after FUSE itself has been brought up
         """
@@ -119,6 +123,15 @@ class Pyarr(fuse.Fuse):
         logger.info("getattr -- " + str(path))
         if isRarFilePath(path): # is a rarfile
             logging.debug("getattr: on rar archive for path " + str(path))
+
+            # if we run with the no_compressed option and files in a rar file
+            # are compressed, we just present it as a ordinary directory
+            rf = rarfile.RarFile(path)
+            for n in rf.namelist():
+                inf = rf.getinfo(n)
+                if self.no_compressed and int(chr(inf.compress_type)) > 0:
+                    return os.lstat('.' + path)
+
             original_stat = os.lstat('.' + path)
             fake_stat = fuse.Stat()
             fake_stat.st_mode = stat.S_IFDIR | 0755
@@ -287,7 +300,7 @@ PyarrFS mirror the filesystem tree from some point on, allowing RAR archives to
 
 """ + fuse.Fuse.fusage
 
-    server = Pyarr(version="PyarrFS 0.1",
+    server = Pyarr(version="PyarrFS " + __version__,
                  usage=usage)
 
     # TODO: what does multithreaded really mean?
@@ -298,6 +311,7 @@ PyarrFS mirror the filesystem tree from some point on, allowing RAR archives to
     server.multithreaded = False
 
     server.parser.add_option('-r', '--root', dest='root', metavar="PATH", default=server.root, help="mirror filesystem from under PATH [default: %default]")
+    server.parser.add_option('-n', '--no-compressed', action='store_true', dest='no_compressed', default=False, help="Disable compressed files")
     server.parser.add_option('-D', '--pydebug', action='store_true', dest='pydebug', default=False, help="enable debug for just PyarrFS (not FUSE) (implies -f)")
     server.parse(values=server, errex=1)
 
